gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[GNUnet-SVN] [gnurl] branch master updated (01774cbb6 -> d9d649f37)


From: gnunet
Subject: [GNUnet-SVN] [gnurl] branch master updated (01774cbb6 -> d9d649f37)
Date: Thu, 21 Sep 2017 02:30:43 +0200

This is an automated email from the git hooks/post-receive script.

ng0 pushed a change to branch master
in repository gnurl.

    from 01774cbb6 gnurl: followup to 25a03ee9c6133cfe1ce809a8ab1528ae7328fe35.
     new 9ab1d3a79 gnurl: include/gnurl/Makefile.am change.
     new d9d649f37 gnURL: Fix doc generation, fix 'make dist'.

The 2 revisions listed above as "new" are entirely new to this
repository and will be described in separate emails.  The revisions
listed as "add" were already present in the repository and have only
been added to this reference.


Summary of changes:
 .gitignore                     | 15 ++++++++-------
 docs/cmdline-opts/gen.pl       | 10 +++++-----
 docs/examples/version-check.pl |  2 +-
 guix-gnurl.scm                 | 14 +++++++++++++-
 include/gnurl/Makefile.am      | 19 -------------------
 maketgz                        |  4 ++--
 scripts/Makefile.am            |  2 +-
 scripts/log2changes.pl         |  4 ++--
 scripts/updatemanpages.pl      |  2 +-
 scripts/zsh.pl                 | 12 ++++++------
 tests/fuzz/Makefile.am         | 10 ++++------
 tests/nroff-scan.pl            |  6 +++---
 12 files changed, 46 insertions(+), 54 deletions(-)

diff --git a/.gitignore b/.gitignore
index e3c2f3455..13d10a67f 100644
--- a/.gitignore
+++ b/.gitignore
@@ -38,18 +38,19 @@ config.log
 config.status
 config.sub
 configure
-curl-*.tar.bz2
-curl-*.tar.gz
-curl-*.tar.xz
-curl-*.zip
-curl-config
+gnurl-*.tar.bz2
+gnurl-*.tar.gz
+gnurl-*.tar.xz
+gnurl-*.zip
+gnurl-config
 depcomp
 install-sh
-libcurl.pc
+libgnurl.pc
 libtool
 ltmain.sh
 missing
 mkinstalldirs
 tags
 test-driver
-scripts/_curl
+scripts/_gnurl
+\#*\#
\ No newline at end of file
diff --git a/docs/cmdline-opts/gen.pl b/docs/cmdline-opts/gen.pl
index 73ea6d47b..6f67be6c1 100755
--- a/docs/cmdline-opts/gen.pl
+++ b/docs/cmdline-opts/gen.pl
@@ -4,7 +4,7 @@
 
 This script generates the manpage.
 
-Example: gen.pl mainpage > curl.1
+Example: gen.pl mainpage > gnurl.1
 
 Dev notes:
 
@@ -92,7 +92,7 @@ sub protocols {
 sub added {
     my ($standalone, $data)address@hidden;
     if($standalone) {
-        return ".SH \"ADDED\"\nAdded in curl version $data\n";
+        return ".SH \"ADDED\"\nAdded in gnurl version $data\n";
     }
     else {
         return "Added in $data. ";
@@ -179,9 +179,9 @@ sub single {
     }
 
     if($standalone) {
-        print ".TH curl 1 \"30 Nov 2016\" \"curl 7.52.0\" \"curl manual\"\n";
+        print ".TH gnurl 1 \"30 Nov 2016\" \"gnurl 7.52.0\" \"curl manual\"\n";
         print ".SH OPTION\n";
-        print "curl $opt\n";
+        print "gnurl $opt\n";
     }
     else {
         print ".IP \"$opt\"\n";
@@ -209,7 +209,7 @@ sub single {
     }
     if($requires) {
         my $l = manpageify($long);
-        push @foot, "$l requires that the underlying libcurl".
+        push @foot, "$l requires that the underlying libgnurl".
             " was built to support $requires. ";
     }
     if($mutexed) {
diff --git a/docs/examples/version-check.pl b/docs/examples/version-check.pl
index 074e50d8c..5a362e464 100755
--- a/docs/examples/version-check.pl
+++ b/docs/examples/version-check.pl
@@ -36,7 +36,7 @@
 #    version-check.pl [source file]
 #
 
-open(S, "<../libcurl/symbols-in-versions") || die;
+open(S, "<../libgnurl/symbols-in-versions") || die;
 
 my %doc;
 my %rem;
diff --git a/guix-gnurl.scm b/guix-gnurl.scm
index f08f17f6d..80c93ebff 100644
--- a/guix-gnurl.scm
+++ b/guix-gnurl.scm
@@ -23,9 +23,11 @@
  (ice-9 popen)
  (ice-9 match)
  (ice-9 rdelim)
+ (srfi srfi-1)
  (guix packages)
  (guix build-system gnu)
  (guix gexp)
+ (guix utils)
  ((guix build utils) #:select (with-directory-excursion))
  (gnu packages)
  (gnu packages base)
@@ -41,6 +43,16 @@
     (version (string-append "7.55.1-" "dev"))
     (source
      (local-file %source-dir
-                 #:recursive? #t))))
+                 #:recursive? #t))
+    (arguments
+     (substitute-keyword-arguments (package-arguments gnurl)
+       ((#:phases phases)
+        `(modify-phases ,phases
+           (add-after 'build 'dist
+             (lambda _
+               (zero? (system* "maketgz" "7.55.1-3"))))))))))
+           ;; (add-after 'check 'dist-check
+           ;;   (lambda _
+           ;;     (zero? (system* "make" "distcheck"))))))))))
 
 gnurl-git
diff --git a/include/gnurl/Makefile.am b/include/gnurl/Makefile.am
index a7c8b47c5..09f6cb152 100644
--- a/include/gnurl/Makefile.am
+++ b/include/gnurl/Makefile.am
@@ -25,25 +25,6 @@ pkginclude_HEADERS = \
 
 pkgincludedir= $(includedir)/gnurl
 
-# curlbuild.h does not exist in the git tree. When the original libcurl
-# source code distribution archive file is created, curlbuild.h.dist is
-# renamed to curlbuild.h and included in the tarball so that it can be
-# used directly on non-configure systems.
-#
-# The distributed curlbuild.h will be overwritten on configure systems
-# when the configure script runs, with one that is suitable and specific
-# to the library being configured and built.
-#
-# curlbuild.h.in is the distributed template file from which the configure
-# script creates curlbuild.h at library configuration time, overwiting the
-# one included in the distribution archive.
-#
-# curlbuild.h.dist is not included in the source code distribution archive.
-
-EXTRA_DIST = curlbuild.h.in
-
-DISTCLEANFILES = curlbuild.h
-
 checksrc:
        @@PERL@ $(top_srcdir)/lib/checksrc.pl -D$(top_srcdir)/include/gnurl 
$(pkginclude_HEADERS)
 
diff --git a/maketgz b/maketgz
index 83cd4e7fb..e26e9d7cd 100755
--- a/maketgz
+++ b/maketgz
@@ -61,7 +61,7 @@ numeric=`perl -e 'printf("%02x%02x%02x\n", '"$major, $minor, 
$patch);"`
 
 HEADER=include/gnurl/curlver.h
 CHEADER=src/tool_version.h
-PLIST=lib/libcurl.plist
+PLIST=lib/libgnurl.plist
 
 if test -z "$only"; then
     ext=".dist"
@@ -208,7 +208,7 @@ makezip ()
 zip="gnurl-$version.zip"
 echo "Generating $zip"
 tempdir=".builddir"
-makezip
+#makezip
 
 echo "------------------"
 echo "maketgz report:"
diff --git a/scripts/Makefile.am b/scripts/Makefile.am
index 33c01535d..e9e97ef75 100644
--- a/scripts/Makefile.am
+++ b/scripts/Makefile.am
@@ -22,7 +22,7 @@
 ZSH_FUNCTIONS_DIR = @ZSH_FUNCTIONS_DIR@
 PERL = @PERL@
 
-ZSH_COMPLETION_FUNCTION_FILENAME = _curl
+ZSH_COMPLETION_FUNCTION_FILENAME = _gnurl
 
 all-local: $(ZSH_COMPLETION_FUNCTION_FILENAME)
 
diff --git a/scripts/log2changes.pl b/scripts/log2changes.pl
index 667daabf0..4e35e9cad 100755
--- a/scripts/log2changes.pl
+++ b/scripts/log2changes.pl
@@ -1,4 +1,4 @@
-#!/usr/bin/perl
+#!/usr/bin/env perl
 
 # git log --pretty=fuller --no-color --date=short --decorate=full
 
@@ -32,7 +32,7 @@ while(<STDIN>) {
     if($l =~/^commit ([[:xdigit:]]*) ?(.*)/) {
         $co = $1;
         my $ref = $2;
-        if ($ref =~ /refs\/tags\/curl-([0-9_]*)/) {
+        if ($ref =~ /refs\/tags\/gnurl-([0-9_]*)/) {
             $tag = $1;
             $tag =~ tr/_/./;
         }
diff --git a/scripts/updatemanpages.pl b/scripts/updatemanpages.pl
index 6a58dbd42..e144bad11 100755
--- a/scripts/updatemanpages.pl
+++ b/scripts/updatemanpages.pl
@@ -1,4 +1,4 @@
-#!/usr/bin/perl
+#!/usr/bin/env perl
 #***************************************************************************
 #                                  _   _ ____  _
 #  Project                     ___| | | |  _ \| |
diff --git a/tests/fuzz/Makefile.am b/tests/fuzz/Makefile.am
index d8978dbda..259b86c4f 100644
--- a/tests/fuzz/Makefile.am
+++ b/tests/fuzz/Makefile.am
@@ -26,15 +26,13 @@ AUTOMAKE_OPTIONS = foreign nostdinc
 # being currently built and tested are searched before the library which
 # might possibly already be installed in the system.
 #
-# $(top_builddir)/include/gnurl for generated curlbuild.h included from curl.h
-# $(top_builddir)/include for generated curlbuild.h inc. from lib/curl_setup.h
+
+
 # $(top_srcdir)/include is for libcurl's external include files
 # $(top_builddir)/lib is for libcurl's generated lib/curl_config.h file
 # $(top_srcdir)/lib for libcurl's lib/curl_setup.h and other "borrowed" files
 
-AM_CPPFLAGS = -I$(top_builddir)/include/gnurl \
-              -I$(top_builddir)/include      \
-              -I$(top_srcdir)/include        \
+AM_CPPFLAGS = -I$(top_srcdir)/include        \
               -I$(top_builddir)/lib          \
               -I$(top_srcdir)/lib            \
               -I$(top_srcdir)/tests/fuzz
@@ -42,7 +40,7 @@ AM_CPPFLAGS = -I$(top_builddir)/include/gnurl \
 EXTRA_DIST = Makefile.inc CMakeLists.txt
 
 LIBS = -lpthread -lFuzzer -lstdc++ -lm
-LDFLAGS = -L/usr/lib/llvm-5.0/lib #-L/home/daniel/src/Fuzzer/
+LDFLAGS = -L/usr/lib/llvm-5.0/lib
 
 LDADD = $(top_builddir)/lib/libgnurl.la      \
         @LDFLAGS@ @LIBCURL_LIBS@
diff --git a/tests/nroff-scan.pl b/tests/nroff-scan.pl
index 393068cd3..1ab780f56 100644
--- a/tests/nroff-scan.pl
+++ b/tests/nroff-scan.pl
@@ -66,7 +66,7 @@ sub file {
                 print STDERR "error: $f:$line: missing \\fP after $str\n";
                 $errors++;
             }
-            if($str =~ /((libcurl|curl)([^ ]*))\(3\)/i) {
+            if($str =~ /((libcurl|gnurl)([^ ]*))\(3\)/i) {
                 my $man = "$1.3";
                 if(!manpresent($man)) {
                     print STDERR "error: $f:$line: refering to non-existing 
man page $man\n";
@@ -78,13 +78,13 @@ sub file {
                 }
             }
         }
-        if($l =~ /(curl([^ ]*)\(3\))/i) {
+        if($l =~ /(gnurl([^ ]*)\(3\))/i) {
             print STDERR "error: $f:$line: non-referencing $1\n";
             $errors++;
         }
         if($l =~ /^\.BR (.*)/) {
             my $i= $1;
-            while($i =~ s/((lib|)curl([^ ]*)) *\"\(3\)(,|) *\" *//i ) {
+            while($i =~ s/((lib|)gnurl([^ ]*)) *\"\(3\)(,|) *\" *//i ) {
                 my $man = "$1.3";
                 if(!manpresent($man)) {
                     print STDERR "error: $f:$line: refering to non-existing 
man page $man\n";

diff --git a/scripts/zsh.pl b/scripts/zsh.pl
index f0d8c195f..5b5ad13e7 100755
--- a/scripts/zsh.pl
+++ b/scripts/zsh.pl
@@ -5,7 +5,7 @@
 use strict;
 use warnings;
 
-my $curl = $ARGV[0] || 'curl';
+my $gnurl = $ARGV[0] || 'gnurl';
 
 my $regex = '\s+(?:(-[^\s]+),\s)?(--[^\s]+)\s([^\s.]+)?\s+(.*)';
 my @opts = parse_main_opts('--help', $regex);
@@ -16,9 +16,9 @@ $opts_str .= qq{  $_ \\\n} foreach (@opts);
 chomp $opts_str;
 
 my $tmpl = <<"EOS";
-#compdef curl
+#compdef gnurl
 
 # curl zsh completion
 
 local curcontext="\$curcontext" state state_descr line
 typeset -A opt_args
@@ -78,11 +78,11 @@ sub trim { my $s = shift; $s =~ s/^\s+|\s+$//g; return $s };
 
 sub call_curl {
     my ($cmd) = @_;
-    my $output = `"$curl" $cmd`;
+    my $output = `"$gnurl" $cmd`;
     if ($? == -1) {
-        die "Could not run curl: $!";
+        die "Could not run gnurl: $!";
     } elsif ((my $exit_code = $? >> 8) != 0) {
-        die "curl returned $exit_code with output:\n$output";
+        die "gnurl returned $exit_code with output:\n$output";
     }
     return split /\n/, $output;
 }
@@ -16,9 +16,9 @@ $opts_str .= qq{  $_ \\\n} foreach (@opts);
 
-# curl zsh completion
+# gnurl zsh completion
 
 local curcontext="\$curcontext" state state_descr line
-- 
To stop receiving notification emails like this one, please contact
address@hidden



reply via email to

[Prev in Thread] Current Thread [Next in Thread]